==> egov-common-1.0.5-sources.jar: com/gtis/plat/vo/PfWorkFlowDefineVo.java <==
package com.gtis.plat.vo;

import org.apache.struts2.json.annotations.JSON;

import java.io.Serializable;
import java.util.Date;

public class PfWorkFlowDefineVo implements Serializable {

    private static final long serialVersionUID = 4627894285163333374L;
    String workflowDefinitionId;
    String workflowCode;
    String workflowName;
    int timeLimit;
    String priority;
    String remark;
    Date createTime;
    String createUrl;
    int createHeight;
    int createWidth;
    String workflowEventBean;
    String regionCode;
    String businessId;
    PfBusinessVo businessVo;
    byte[] workFlowImage;
    String eventShell;
    Date modifyDate;
    private int isMonitor;
    /**
     * 实例的详细信息访问路径
     */
    private String detailUrl;

    public String getDetailUrl() {
        return detailUrl;
    }

    public void setDetailUrl(String detailUri) {
        this.detailUrl = detailUri;
    }

    public Date getModifyDate() {
        return modifyDate;
    }

    public void setModifyDate(Date modifyDate) {
        this.modifyDate = modifyDate;
    }

    public String getEventShell() {
        return eventShell;
    }

    public void setEventShell(String eventShell) {
        this.eventShell = eventShell;
    }

    public byte[] getWorkFlowImage() {
        return workFlowImage;
    }

    public void setWorkFlowImage(byte[] workFlowImage) {
        this.workFlowImage = workFlowImage;
    }

    @JSON(serialize = false)
    public String getBusinessId() {
        return businessId;
    }

    public void setBusinessId(String businessId) {
        this.businessId = businessId;
    }

    @JSON(serialize = false)
    public String getRegionCode() {
        return regionCode;
    }

    public void setRegionCode(String regionCode) {
        this.regionCode = regionCode;
    }

    public String getWorkflowDefinitionId() {
        return workflowDefinitionId;
    }

    public void setWorkflowDefinitionId(String workflowDefinitionId) {
        this.workflowDefinitionId = workflowDefinitionId;
    }

    @JSON(serialize = false)
    public String getWorkflowCode() {
        return workflowCode;
    }

    public void setWorkflowCode(String workflowCode) {
        this.workflowCode = workflowCode;
    }

    public String getWorkflowName() {
        return workflowName;
    }

    public void setWorkflowName(String workflowName) {
        this.workflowName = workflowName;
    }

    @JSON(serialize = false)
    public int getTimeLimit() {
        return timeLimit;
    }

    public void setTimeLimit(int timeLimit) {
        this.timeLimit = timeLimit;
    }

    @JSON(serialize = false)
    public String getPriority() {
        return priority;
    }

    public void setPriority(String priority) {
        this.priority = priority;
    }

    @JSON(serialize = false)
    public String getRemark() {
        return remark;
    }

    public void setRemark(String remark) {
        this.remark = remark;
    }

    @JSON(serialize = false)
    public Date getCreateTime() {
        return createTime;
    }

    public void setCreateTime(Date createTime) {
        this.createTime = createTime;
    }

    @JSON(serialize = false)
    public String getCreateUrl() {
        return createUrl;
    }

    public void setCreateUrl(String createUrl) {
        this.createUrl = createUrl;
    }

    @JSON(serialize = false)
    public int getCreateHeight() {
        return createHeight;
    }

    public void setCreateHeight(int createHeight) {
        this.createHeight = createHeight;
    }

    @JSON(serialize = false)
    public int getCreateWidth() {
        return createWidth;
    }

    public void setCreateWidth(int createWidth) {
        this.createWidth = createWidth;
    }

    @JSON(serialize = false)
    public String getWorkflowEventBean() {
        return workflowEventBean;
    }

    public void setWorkflowEventBean(String workflowEventBean) {
        this.workflowEventBean = workflowEventBean;
    }

    @JSON(serialize = false)
    public PfBusinessVo getBusinessVo() {
        return businessVo;
    }

    public void setBusinessVo(PfBusinessVo businessVo) {
        this.businessVo = businessVo;
    }

    public int getIsMonitor() {
        return isMonitor;
    }

    public void setIsMonitor(int isMonitor) {
        this.isMonitor = isMonitor;
    }

    /**
     * 获取流程定义模型
     *
     * @return
     */

//	public WorkFlowXml getXmlModel() {
//		return xmlModel;
//	}
//
//	public void setXmlModel(WorkFlowXml xmlModel) {
//		this.xmlModel = xmlModel;
//	}

}

==> egov-common-1.0.8-sources.jar: com/gtis/plat/vo/PfWorkFlowDefineVo.java <==
package com.gtis.plat.vo;

import org.apache.struts2.json.annotations.JSON;

import java.io.Serializable;
import java.util.Date;

public class PfWorkFlowDefineVo implements Serializable {

    private static final long serialVersionUID = 4627894285163333374L;
    String workflowDefinitionId;
    String workflowCode;
    String workflowName;
    int timeLimit;
    String priority;
    String remark;
    Date createTime;
    String createUrl;
    int createHeight;
    int createWidth;
    String workflowEventBean;
    String regionCode;
    String businessId;
    PfBusinessVo businessVo;
    byte[] workFlowImage;
    String eventShell;
    Date modifyDate;
    private int isMonitor;
    private String groupId;
    PfResourceGroupVo resourceGroupVo;
    /**
     * 实例的详细信息访问路径
     */
    private String detailUrl;
    @JSON(serialize = false)
    public String getDetailUrl() {
        return detailUrl;
    }

    public void setDetailUrl(String detailUri) {
        this.detailUrl = detailUri;
    }
    @JSON(serialize = false)
    public Date getModifyDate() {
        return modifyDate;
    }

    public void setModifyDate(Date modifyDate) {
        this.modifyDate = modifyDate;
    }
    @JSON(serialize = false)
    public String getEventShell() {
        return eventShell;
    }

    public void setEventShell(String eventShell) {
        this.eventShell = eventShell;
    }

    @JSON(serialize = false)
    public byte[] getWorkFlowImage() {
        return workFlowImage;
    }

    public void setWorkFlowImage(byte[] workFlowImage) {
        this.workFlowImage = workFlowImage;
    }

    @JSON(serialize = false)
    public String getBusinessId() {
        return businessId;
    }

    public void setBusinessId(String businessId) {
        this.businessId = businessId;
    }

    @JSON(serialize = false)
    public String getRegionCode() {
        return regionCode;
    }

    public void setRegionCode(String regionCode) {
        this.regionCode = regionCode;
    }

    public String getWorkflowDefinitionId() {
        return workflowDefinitionId;
    }

    public void setWorkflowDefinitionId(String workflowDefinitionId) {
        this.workflowDefinitionId = workflowDefinitionId;
    }

    @JSON(serialize = false)
    public String getWorkflowCode() {
        return workflowCode;
    }

    public void setWorkflowCode(String workflowCode) {
        this.workflowCode = workflowCode;
    }

    public String getWorkflowName() {
        return workflowName;
    }

    public void setWorkflowName(String workflowName) {
        this.workflowName = workflowName;
    }

    @JSON(serialize = false)
    public int getTimeLimit() {
        return timeLimit;
    }

    public void setTimeLimit(int timeLimit) {
        this.timeLimit = timeLimit;
    }

    @JSON(serialize = false)
    public String getPriority() {
        return priority;
    }

    public void setPriority(String priority) {
        this.priority = priority;
    }

    @JSON(serialize = false)
    public String getRemark() {
        return remark;
    }

    public void setRemark(String remark) {
        this.remark = remark;
    }

    @JSON(serialize = false)
    public Date getCreateTime() {
        return createTime;
    }

    public void setCreateTime(Date createTime) {
        this.createTime = createTime;
    }

    @JSON(serialize = false)
    public String getCreateUrl() {
        return createUrl;
    }

    public void setCreateUrl(String createUrl) {
        this.createUrl = createUrl;
    }

    @JSON(serialize = false)
    public int getCreateHeight() {
        return createHeight;
    }

    public void setCreateHeight(int createHeight) {
        this.createHeight = createHeight;
    }

    @JSON(serialize = false)
    public int getCreateWidth() {
        return createWidth;
    }

    public void setCreateWidth(int createWidth) {
        this.createWidth = createWidth;
    }

    @JSON(serialize = false)
    public String getWorkflowEventBean() {
        return workflowEventBean;
    }

    public void setWorkflowEventBean(String workflowEventBean) {
        this.workflowEventBean = workflowEventBean;
    }

    @JSON(serialize = false)
    public PfBusinessVo getBusinessVo() {
        return businessVo;
    }

    public void setBusinessVo(PfBusinessVo businessVo) {
        this.businessVo = businessVo;
    }

    @JSON(serialize = false)
    public int getIsMonitor() {
        return isMonitor;
    }

    public void setIsMonitor(int isMonitor) {
        this.isMonitor = isMonitor;
    }

    /**
     * 获取流程定义模型
     *
     * @return
     */

//	public WorkFlowXml getXmlModel() {
//		return xmlModel;
//	}
//
//	public void setXmlModel(WorkFlowXml xmlModel) {
//		this.xmlModel = xmlModel;
//	}

    @JSON(serialize = false)
    public String getGroupId() {
        return groupId;
    }

    public void setGroupId(String groupId) {
        this.groupId = groupId;
    }
    @JSON(serialize = false)
    public PfResourceGroupVo getResourceGroupVo() {
        return resourceGroupVo;
    }

    public void setResourceGroupVo(PfResourceGroupVo resourceGroupVo) {
        this.resourceGroupVo = resourceGroupVo;
    }
}
